.. Django IPRestrict documentation master file, created by
   sphinx-quickstart on Wed Aug 15 11:50:03 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Django IP Restrict
==================

Django IPRestrict is an app + middleware to restrict access to all or sections of a Django project by client IP ranges.

The code is released under BSD license and it is hosted on github at https://github.com/muccg/django-iprestrict/.


Table of Contents
=================

.. toctree::
    :maxdepth: 2

    installation
    configuration
    changing_and_reloading_rules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

